@@ -111,6 +111,8 @@ module AsciidoctorExtensions
       bpmn
       bytefield
       c4plantuml
+      d2
+      dbml
       ditaa
       erd
       excalidraw
@@ -129,6 +131,7 @@ module AsciidoctorExtensions
       vegalite
       wavedrom
       structurizr
+      diagramsnet
     ].freeze
   end
 
